@@ -702,7 +702,7 @@ for (i = 0; i <= GRfoodlevel[foodno]; i++) levelminbuf[i] = oldlevelminbuf[i];
 for (i = 0; i <= GRfoodlevel[foodno]; i++) levelmaxbuf[i] = oldlevelmaxbuf[i];
 if (GRlowestlevelchange[foodno] < GRfoodlevel[foodno])
  {
- for (i = 0;  i <= GRlowestlevelchange[foodno]; i++) levelmaxbuf[i] = oldlevelcumbuf[i];
+ levelmaxbuf[GRlowestlevelchange[foodno]] = oldlevelcumbuf[GRlowestlevelchange[foodno]];
  levelmaxbuf[0] = GRlowestlevelchange[foodno];
  }
 if (foodno == 0)
@@ -715,9 +715,12 @@ prevquanta = levelcumbuf[GRlowestlevelchange[foodno]];
 for (i = GRlowestlevelchange[foodno]; i <= GRfoodlevel[foodno]; i++) levelcumbuf[i] = 0;
 availquanta = levelminbuf[0] - levelcumbuf[0];
 
-max = availquanta < prevquanta ? availquanta : prevquanta;
-localavailquanta = levelmaxbuf[levelmaxbuf[0]] - levelcumbuf[levelmaxbuf[0]];
-if (GRlowestlevelchange[foodno] == GRfoodlevel[foodno] && max > localavailquanta) max = localavailquanta;
+localavailquanta = max = availquanta < prevquanta ? availquanta : prevquanta;
+if (GRlowestlevelchange[foodno] == GRfoodlevel[foodno])
+ {
+ for (i = 1; i <= levelmaxbuf[0]; i++) if (localavailquanta > levelmaxbuf[i] - levelcumbuf[i]) localavailquanta = levelmaxbuf[i] - levelcumbuf[i];
+ max = localavailquanta;
+ }
 
 if (GRlowestlevelchange[foodno] <= 1)
  {
