@@ -35,7 +35,7 @@ char nutdir1[]=".nutdb";
 char nutdir1[]=NUTDIR ;
 #endif
 
-char USDAjoined1[] = "sr20.nut";
+char USDAjoined1[] = "sr21.nut";
 char globalFOOD1[] = "FOOD_DES.txt";
 char globalNUT1[] = "NUT_DATA.txt";
 char globalWEIGHT1[] = "WEIGHT.txt";
@@ -45,6 +45,7 @@ char localNUT1[] = "NUT_DATA.txt";
 char localWEIGHT1[] = "WEIGHT.txt";
 char foodfile1[] = "food.db";
 char mealfile1[] = "meal.db";
+char mealexpfile1[] = "meal.exp";
 char theusualfile1[] = "theusual.db";
 char optionsfile1[] = "options.db";
 char localOPTIONS1[] = "OPTIONS.txt";
@@ -61,6 +62,7 @@ char localNUT[2000];
 char localWEIGHT[2000];
 char foodfile[2000];
 char mealfile[2000];
+char mealexpfile[2000];
 char theusualfile[2000];
 char optionsfile[2000];
 char localOPTIONS[2000];
@@ -879,16 +881,17 @@ strcpy(subuser,sub);
  mkdir (nutdir, 0700 );
  sprintf(nutdirsubuser,"%s/%s","NUTDB",subuser);
  mkdir (nutdirsubuser, 0700 );
- sprintf(USDAjoined,"%s/%s","NUTSR20",USDAjoined1);
- sprintf(globalFOOD,"%s/%s","NUTSR20",globalFOOD1);
- sprintf(globalNUT,"%s/%s","NUTSR20",globalNUT1);
- sprintf(globalWEIGHT,"%s/%s","NUTSR20",globalWEIGHT1);
- sprintf(weightlib,"%s/%s","NUTSR20",weightlib1);
+ sprintf(USDAjoined,"%s/%s","NUTSR21",USDAjoined1);
+ sprintf(globalFOOD,"%s/%s","NUTSR21",globalFOOD1);
+ sprintf(globalNUT,"%s/%s","NUTSR21",globalNUT1);
+ sprintf(globalWEIGHT,"%s/%s","NUTSR21",globalWEIGHT1);
+ sprintf(weightlib,"%s/%s","NUTSR21",weightlib1);
  sprintf(localFOOD,"%s/%s/%s","NUTDB",subuser,localFOOD1);
  sprintf(localNUT,"%s/%s/%s","NUTDB",subuser,localNUT1);
  sprintf(localWEIGHT,"%s/%s/%s","NUTDB",subuser,localWEIGHT1);
  sprintf(foodfile,"%s/%s/%s","NUTDB",subuser,foodfile1);
  sprintf(mealfile,"%s/%s/%s","NUTDB",subuser,mealfile1);
+ sprintf(mealexpfile,"%s/%s/%s","NUTDB",subuser,mealexpfile1);
  sprintf(theusualfile,"%s/%s/%s","NUTDB",subuser,theusualfile1);
  sprintf(optionsfile,"%s/%s/%s","NUTDB",subuser,optionsfile1);
  sprintf(localOPTIONS,"%s/%s/%s","NUTDB",subuser,localOPTIONS1);
@@ -908,6 +911,7 @@ sprintf(localNUT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localNUT1);
 sprintf(localWEIGHT,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localWEIGHT1);
 sprintf(foodfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,foodfile1);
 sprintf(mealfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealfile1);
+sprintf(mealexpfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,mealexpfile1);
 sprintf(theusualfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,theusualfile1);
 sprintf(optionsfile,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,optionsfile1);
 sprintf(localOPTIONS,"%s/%s/%s/%s",getenv("HOME"),nutdir1,subuser,localOPTIONS1);
