@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2007 by Jim Jozwiak.
+    Copyright (C) 1996-2008 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 
 #define MAX_FOOD 9000
 #define DV_COUNT 39
+#define GRAMS_IN_OUNCE 28.349523
 
 struct food
  {
@@ -91,6 +92,6 @@ float dv_fat(void);
 float dv_cho(void);
 float dv_pro(void);
 char *format_serving(char *, float *, struct food *);
-float n6hufa(float, float, float, float, float);
+float n6hufa(float, float, float, float, float, float);
 
 #endif
